ska.contrib.django.ska.views package
====================================

Submodules
----------

ska.contrib.django.ska.views.constance\_views module
----------------------------------------------------

.. automodule:: ska.contrib.django.ska.views.constance_views
    :members:
    :undoc-members:
    :show-inheritance:

ska.contrib.django.ska.views.default\_views module
--------------------------------------------------

.. automodule:: ska.contrib.django.ska.views.default_views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ska.contrib.django.ska.views
    :members:
    :undoc-members:
    :show-inheritance:
